<?php

class Freevent_Event_Post_Type {

	const TEXTDOMAIN = 'freevent';
	
	public static function load() {
		add_action( 'init', array( __CLASS__, 'register' ) );
	}

	public static function load_admin() {
		add_action( 'admin_init', array( __CLASS__, 'register_meta_box' ) );
		add_action( 'save_post', array( __CLASS__, 'save_post_freevent' ), 10, 3 );
		add_action( 'admin_enqueue_scripts', array(__CLASS__, 'enqueue_admin_scripts') );
	}

	static function register() {
		$labels = array(
			'name'               => _x( 'Events', 'post type general name', self::TEXTDOMAIN ),
			'singular_name'      => _x( 'Event', 'post type singular name', self::TEXTDOMAIN ),
			'menu_name'          => _x( 'Events', 'admin menu', self::TEXTDOMAIN ),
			'name_admin_bar'     => _x( 'Event', 'add new on admin bar', self::TEXTDOMAIN ),
			'add_new'            => _x( 'Add New', 'book', self::TEXTDOMAIN ),
			'add_new_item'       => __( 'Add New Event', self::TEXTDOMAIN ),
			'new_item'           => __( 'New Event', self::TEXTDOMAIN ),
			'edit_item'          => __( 'Edit Event', self::TEXTDOMAIN ),
			'view_item'          => __( 'View Event', self::TEXTDOMAIN ),
			'all_items'          => __( 'All Events', self::TEXTDOMAIN ),
			'search_items'       => __( 'Search Events', self::TEXTDOMAIN ),
			'parent_item_colon'  => __( 'Parent Events:', self::TEXTDOMAIN ),
			'not_found'          => __( 'No events found.', self::TEXTDOMAIN ),
			'not_found_in_trash' => __( 'No events found in Trash.', self::TEXTDOMAIN )
		);

		$args = array(
			'labels'             => $labels,
			'description'        => __( 'Description.', self::TEXTDOMAIN ),
			'public'             => true,
			'publicly_queryable' => true,
			'show_ui'            => true,
			'show_in_menu'       => true,
			'query_var'          => true,
			'rewrite'            => array( 'slug' => 'event' ),
			'has_archive'        => true,
			'hierarchical'       => false,
			'menu_position'      => null,
			'supports'           => array( 'title', 'editor', 'slug' )
		);

		register_post_type( 'freevent', $args );
	}

	static function register_meta_box() {
		add_meta_box( 'freevent_event_details', 'Event Details', array(__CLASS__, 'event_details_metabox' ), 'freevent', 'normal', 'high' );
		add_meta_box( 'freevent_coupon_details', 'Coupon Codes', array(__CLASS__, 'event_coupon_metabox' ), 'freevent', 'normal', 'high' );
	}

	static function event_details_metabox() {
		global $pagenow;
		global $post;

		$startDate = date('Y-m-d');
		$endDate = date('Y-m-d');

		$saleStartDate = date('Y-m-d');
		$saleEndDate = date('Y-m-d');

		$maxTickets = '';
		$maxTicketsPerOrder = 1;

		$adminEmail = get_bloginfo('admin_email');

		if ($pagenow != 'post-new.php') {
			$startDate = get_post_meta($post->ID, 'start_date', true);
			$endDate = get_post_meta($post->ID, 'end_date', true);
			$maxTickets = get_post_meta($post->ID, 'max_tickets', true);
			$adminEmail = get_post_meta($post->ID, 'admin_email', true);
			$maxTicketsPerOrder = get_post_meta($post->ID, 'max_tickets_per_order', true);
		}

		echo '<h2>Event Dates</h2>';

		echo '<div><label for="start_date">Start Date:</label> <input type="text" name="start_date" id="start_date" class="datepicker" value="' . esc_attr($startDate) . '" /></div>';
		echo '<div><label for="end_date">End Date:</label> <input type="text" name="end_date" id="end_date" class="datepicker" value="' . esc_attr($endDate) . '" /></div>';

		echo '<h2>Ticket Details</h2>';

		echo '<div><label for="max_tickets">Maximum Tickets For Event:</label> <input type="number" name="max_tickets" id="max_tickets" value="' . esc_attr($maxTickets) . '" /></div>';
		echo '<div><label for="sale_start_date">Tickets Go On Sale:</label> <input type="text" name="sale_start_date" id="sale_start_date" class="datepicker" value="' . esc_attr($saleStartDate) . '" /></div>';
		echo '<div><label for="sale_end_date">Ticket Sales End:</label> <input type="text" name="sale_end_date" id="sale_end_date" class="datepicker" value="' . esc_attr($saleEndDate) . '" /></div>';
		echo '<div><label for="max_tickets_per_order">Maximum Tickets Per Order:</label> <input type="number" name="max_tickets_per_order" id="max_tickets_per_order" value="' . esc_attr($maxTicketsPerOrder) . '" /></div>';

		echo '<h2>Send receipt To:</h2>';

		echo '<div><label for="start_date">Event Admin\'s E-Mail Address:</label> <input type="email" name="admin_email" id="admin_email" value="' . esc_attr($adminEmail) . '" /></div>';

	}

	static function event_coupon_metabox() {
		global $post;
		global $pagenow;

		echo '<table><thead><tr><th>Coupon Code</th><th>Description</th><th>Maximum Available</th></tr></thead><tbody>';

		$rows = 3;

		$allCoupons = get_post_meta($post->ID, 'coupon_codes', true);
		$allCoupons = maybe_unserialize($allCoupons);

		for ($row = 0; $row < $rows; $row++) {
			if ($pagenow != 'post-new.php') {
				echo '<tr>';
				echo '<td><input type="text" class="coupon_code" name="coupon_code[]" id="coupon_code_' . $row . '" maxlength="20" value="' . esc_attr($allCoupons[$row]['code']) . '"></td>';
				echo '<td><input type="text" class="coupon_description" name="coupon_description[]" id="coupon_description_' . $row . '" maxlength="100" style="width:400px;" value="' . esc_attr($allCoupons[$row]['description']) . '"></td>';
				echo '<td><input type="number"  class="coupon_max" name="coupon_max[]"id="coupon_max_' . $row . '"  maxlength="4" value="' . esc_attr($allCoupons[$row]['maxTickets']) . '"></td>';
				echo '</tr>';
			} else {
				echo '<tr>';
				echo '<td><input type="text" class="coupon_code" name="coupon_code[]" id="coupon_code_' . $row . '" maxlength="20"></td>';
				echo '<td><input type="text" class="coupon_description" name="coupon_description[]" id="coupon_description_' . $row . '" maxlength="100" style="width:400px;"></td>';
				echo '<td><input type="number"  class="coupon_max" name="coupon_max[]"id="coupon_max_' . $row . '"  maxlength="4"></td>';
				echo '</tr>';
			}
		}

		echo '</tbody></table>';
	}

	static function save_post_freevent($post_id, $post, $update) {
		global $_POST;

		if ($post->post_type != 'freevent' || $post->post_status == 'auto-draft') return;

		update_post_meta($post_id, 'start_date', sanitize_text_field($_POST['start_date']));
		update_post_meta($post_id, 'end_date', sanitize_text_field($_POST['end_date']));
		update_post_meta($post_id, 'sale_start_date', sanitize_text_field($_POST['sale_start_date']));
		update_post_meta($post_id, 'sale_end_date', sanitize_text_field($_POST['sale_end_date']));
		update_post_meta($post_id, 'max_tickets', sanitize_text_field($_POST['max_tickets']));
		update_post_meta($post_id, 'admin_email', sanitize_text_field($_POST['admin_email']));
		update_post_meta($post_id, 'max_tickets_per_order', sanitize_text_field($_POST['max_tickets_per_order']));

		// Get Coupons
		$couponCount = count($_POST['coupon_code']);
		$coupons = array();

		for ($i = 0; $i <= $couponCount -1; $i++) {
			$thisCoupon = array();
			$thisCoupon['code'] = $_POST['coupon_code'][$i];
			$thisCoupon['description'] = $_POST['coupon_description'][$i];
			$thisCoupon['maxTickets'] = $_POST['coupon_max'][$i];
			array_push($coupons, $thisCoupon);
		}

		update_post_meta($post_id, 'coupon_codes', serialize($coupons) );
	}

	static function enqueue_admin_scripts() {
		wp_enqueue_script('freevent_admin', plugin_dir_url(__FILE__) . '../js/freevent-admin.js', 1.0, true);
	}

}